@@ -16,10 +16,18 @@ char comment[LINELENGTH];
   putc('(',out);
   comment[0]=0;
 
-  while((tokentype=gettoken(token))!=5 && tokentype!=3)
+  /* while((tokentype=gettoken(token))!=5 && tokentype!=3) */
+  while((tokentype=gettoken(token))!=5)
   {
     if (tokentype==0) { return 1; }
 
+    if (tokentype==3)
+    {
+      fprintf(out,"\n");
+      autoindent();
+      fprintf(out,"   ");
+    }
+      else
     if (tokentype==6)
     { break; }
       else
@@ -34,9 +42,11 @@ char comment[LINELENGTH];
     if (tokentype==7)
     { fprintf(out,"%s",token); }
       else
+/*
     if (tokentype==3)
     { putc('\n',out); continue; }
       else
+*/
     if (strcasecmp(token,"not")==0)
     { fprintf(out,"!"); }
       else
