@@ -209,7 +209,7 @@ int t,l;
   { sprintf(newtoken,"count"); convert_funct(newtoken,"1",0); }
     else
   if (strcasecmp(token,"chr")==0)
-  { sprintf(newtoken,"char"); convert_funct(newtoken,"1",0); }
+  { sprintf(newtoken,"chr"); convert_funct(newtoken,"1",0); }
     else
   if (strcasecmp(token,"asc")==0)
   { sprintf(newtoken,"ord"); convert_funct(newtoken,"1",0); }
