@@ -47,7 +47,7 @@ int tokentype,c;
 
   fprintf(out,"{\n");
   autoindent();
-  fprintf(out,"  global extract($GLOBALS);\n\n");
+  fprintf(out,"  extract($GLOBALS);\n\n");
 
   indent++;
   c=parse_body(0);
