@@ -20,6 +20,7 @@ int setvar;
 int add_isnum,add_session,BOF;
 int infunct,functptr;
 char funct[80][50];
+char classes[4096];
 char global_uid[70];
 char global_passwd[70];
 char global_database[70];
@@ -27,6 +28,7 @@ char global_address[70];
 char global_dsn[70];
 char sessionpool[256][200];
 int sessionptr;
+int classesptr;
 int pngs,y2k,casesense,php;
 int html,spacer;
 char aspextensions[20][10];
@@ -39,4 +41,5 @@ int language;
 int in_body;
 int fixwin95paths;
 int supress;
+int inclass;
 
